@@ -169,7 +169,7 @@ def genome_dataset(bed_path,fasta_path,seq_len=1024,genome_size_control=None,dat
     
     #样本控制
     if genome_size_control!=None:
-        print('使用控制文件，将过滤长度不合文件要求的序列和未在文件中出现的染色体对应的序列')
+        print('使用控制文件，将过滤起止位点不合文件要求的序列和未在文件中出现的染色体对应的序列')
         genome_control = pd.read_csv(genome_size_control,sep='\t',names=['chr','control'])
         control_bed_df = sample_control(new_bed_df,genome_control)
     else:
